import('./utils.js').then(utils => {
  import(/* @vite-ignore */utils.coreVersion()).then(core => {
    core.Sib.register({
      name: 'solid-badge',
      use: [
        core.StoreMixin,
      ],
      attributes: {
        dataType: {
          type: String,
          default: ''
        },
        dataRdfType: {
          type: String,
          default: ''
        }
      },
      initialState: {
        notificationComponent: null,
        refreshCallback: null,
        readCallback: null,
        currentCount: null
      },
      created() {
        this.currentCount = 0;
        this.notificationComponent = null;
        this.refreshCallback = this.populate.bind(this);
        this.readCallback = (event) => {
          if (this.element.querySelector('.counter') &&
            event.detail &&
            event.detail.resource &&
            event.detail.resource['@id'] &&
            event.detail.resource['@id'] == this.resourceId) {
            this.setBadgeRead();
          }
        };

        window.addEventListener('read', this.readCallback); // On read events, remove badge
        window.addEventListener('notificationsCountRefresh', this.refreshCallback);
      },
      detached() {
        window.removeEventListener('read', this.readCallback);
        window.removeEventListener('notificationsCountRefresh', this.refreshCallback);
      },
      empty() { },
      /**
       * Finds and save reference to notification component
       */
      findNotificationComponent() {
        const notificationsElement = document.querySelector('solid-notifications');
        this.notificationComponent = notificationsElement ? notificationsElement.component : null;
      },
      /**
       * Get badge count
       */
      getCount() {
        if (!this.notificationComponent) { // if no notif component
          this.findNotificationComponent(); // try to find it
          if (!this.notificationComponent) { // if still not here, return 0
            console.warn("No solid-notification component found.");
            return 0;
          }
        }

        // then, find unread notifs
          return this.notificationComponent.unreadObjects.filter(unread => {
            return (this.dataType ? unread.type === this.dataType : true)
              && (this.dataRdfType ? unread.objectType === this.dataRdfType : true)
              && (this.resourceId ? unread.objectId === this.resourceId : true)
          }).length;
      },
      empty() {},
      getTemplate(count) {;
        return core.html`<div class="counter" data-nb-unread=${count}>${count}</div>`;
      },
      setBadgeRead() {
        this.currentCount = 0;
        this.render();
      },
      populate() {
        const count = this.getCount();
        if (this.currentCount === count) return; // if no change, no re-render
        this.currentCount = count;
        this.render();
      },
      render() {
        core.render(this.getTemplate(this.currentCount), this.element);
      }
    });
  });
});
